// license-header java merge-point
//
// Attention: generated code (by Metafacade.vsl) - do not modify!
//
package org.andromda.metafacades.uml;

/**
 * <p>
 * Represents an attribute on a classifier. UML2 maps both
 * Attributes and AssociationEnds to Property. A property is a
 * structural feature of a classifier that characterizes instances
 * of the classifier. A property related by ownedAttribute to a
 * classifier (other than an association) represents an attribute
 * and might also represent an association end. It relates an
 * instance of the class to a value or set of values of the type of
 * the attribute. A property represents a set of instances that are
 * owned by a containing classifier instance. Property represents a
 * declared state of one or more instances in terms of a named
 * relationship to a value or values. When a property is an
 * attribute of a classifier, the value or values are related to
 * the instance of the classifier by being held in slots of the
 * instance. The range of valid values represented by the property
 * can be controlled by setting the property's type.
 * </p>
 *
 * Metafacade interface to be used by AndroMDA cartridges.
 */
public interface AttributeFacade
    extends ModelElementFacade
{
    /**
     * Indicates the metafacade type (used for metafacade mappings).
     *
     * @return boolean always <code>true</code>
     */
    public boolean isAttributeFacadeMetaType();

    /**
     * <p>
     * Searches the given feature for the specified tag.
     * </p>
     * <p>
     * If the follow boolean is set to true then the search will
     * continue from the class attribute to the class itself and then
     * up the class hierarchy.
     * </p>
     * @param name String
     * @param follow boolean
     * @return Object
     */
    public Object findTaggedValue(String name, boolean follow);

    /**
     * <p>
     * The default value of the attribute.  This is the value given if
     * no value is defined.
     * </p>
     * @return String
     */
    public String getDefaultValue();

    /**
     * <p>
     * If the attribute is an enumeration literal this represents the
     * owning enumeration. Can be empty.
     * </p>
     * @return EnumerationFacade
     */
    public EnumerationFacade getEnumeration();

    /**
     * <p>
     * Returns the enumeration literal parameters defined by tagged
     * value as a comma separated list.
     * </p>
     * @return String
     */
    public String getEnumerationLiteralParameters();

    /**
     * <p>
     * The value for this attribute if it is an enumeration literal,
     * null otherwise. The default value is returned as a String if it
     * has been specified, if it's not specified this attribute's name
     * is assumed.
     * </p>
     * @return String
     */
    public String getEnumerationValue();

    /**
     * <p>
     * The name of the accessor operation that would retrieve this
     * attribute's value.
     * </p>
     * @return String
     */
    public String getGetterName();

    /**
     * <p>
     * The name of the type that is returned on the accessor and
     * mutator operations,  determined in part by the multiplicity.
     * </p>
     * @return String
     */
    public String getGetterSetterTypeName();

    /**
     * <p>
     * the lower value for the multiplicity
     * </p>
     * <p>
     * -only applicable for UML2
     * </p>
     * @return int
     */
    public int getLower();

    /**
     * <p>
     * Gets the classifier who is the owner of the attributes.
     * </p>
     * @return ClassifierFacade
     */
    public ClassifierFacade getOwner();

    /**
     * <p>
     * The name of the mutator operation that would retrieve this
     * attribute's value.
     * </p>
     * @return String
     */
    public String getSetterName();

    /**
     * <p>
     * The classifier owning this attribute.
     * </p>
     * @return ClassifierFacade
     */
    public ClassifierFacade getType();

    /**
     * <p>
     * the upper value for the multiplicity (will be -1 for *)
     * </p>
     * <p>
     * -only applicable for UML2
     * </p>
     * @return int
     */
    public int getUpper();

    /**
     * <p>
     * True if this attribute can only be set.
     * </p>
     * @return boolean
     */
    public boolean isAddOnly();

    /**
     * <p>
     * True if this attribute can be modified.
     * </p>
     * @return boolean
     */
    public boolean isChangeable();

    /**
     * <p>
     * Indicates if the default value is present.
     * </p>
     * @return boolean
     */
    public boolean isDefaultValuePresent();

    /**
     * <p>
     * If the attribute is derived (its value is computed). UML2 only.
     * UML14 always returns false. Default=false.
     * </p>
     * @return boolean
     */
    public boolean isDerived();

    /**
     * <p>
     * True if this attribute is owned by an enumeration.
     * </p>
     * @return boolean
     */
    public boolean isEnumerationLiteral();

    /**
     * <p>
     * Returns true if enumeration literal parameters exist (defined by
     * tagged value) for the literal.
     * </p>
     * @return boolean
     */
    public boolean isEnumerationLiteralParametersExist();

    /**
     * <p>
     * True if this attribute is owned by an enumeration but is defined
     * as a member variable (NOT a literal).
     * </p>
     * @return boolean
     */
    public boolean isEnumerationMember();

    /**
     * <p>
     * IsLeaf property in the operation. If true, operation is final,
     * cannot be extended or implemented by a descendant.
     * </p>
     * @return boolean
     */
    public boolean isLeaf();

    /**
     * <p>
     * Whether or not this attribute has a multiplicity greater than 1.
     * </p>
     * @return boolean
     */
    public boolean isMany();

    /**
     * <p>
     * Indicates whether or not the attributes are ordered (if
     * multiplicity is greater than 1).
     * </p>
     * @return boolean
     */
    public boolean isOrdered();

    /**
     * <p>
     * Whether or not this attribute can be modified.
     * </p>
     * @return boolean
     */
    public boolean isReadOnly();

    /**
     * <p>
     * Whether or not the multiplicity of this attribute is 1.
     * </p>
     * @return boolean
     */
    public boolean isRequired();

    /**
     * <p>
     * Indicates if this attribute is 'static', meaning it has a
     * classifier scope.
     * </p>
     * @return boolean
     */
    public boolean isStatic();

    /**
     * <p>
     * If the attribute is unique within the Collection type. UML2
     * only. UML14 always returns false. Unique+Ordered determines the
     * implementation Collection type. Default=false.
     * </p>
     * @return boolean
     */
    public boolean isUnique();
}