// license-header java merge-point
//
// Attention: generated code (by Metafacade.vsl) - do not modify!
//
package org.andromda.metafacades.uml;

import java.util.Collection;
import java.util.List;

/**
 * <p>
 * A Classifier is a classification of instances - it describes a
 * set of instances that have features in common. Can specify a
 * generalization hierarchy by referencing its general classifiers.
 * It may be a Class, DataType, PrimitiveType, Association,
 * Collaboration, UseCase, etc. Can specify a generalization
 * hierarchy by referencing its general classifiers. Has the
 * capability to own collaboration uses. These collaboration uses
 * link a collaboration with the classifier to give a description
 * of the workings of the classifier. Classifier is defined to be a
 * kind of templateable element so that a classifier can be
 * parameterized. It is also defined to be a kind of parameterable
 * element so that a classifier can be a formal template parameter.
 * </p>
 *
 * Metafacade interface to be used by AndroMDA cartridges.
 */
public interface ClassifierFacade
    extends GeneralizableElementFacade
{
    /**
     * Indicates the metafacade type (used for metafacade mappings).
     *
     * @return boolean always <code>true</code>
     */
    public boolean isClassifierFacadeMetaType();

    /**
     * <p>
     * Return the attribute which name matches the parameter
     * </p>
     * @param name String
     * @return AttributeFacade
     */
    public AttributeFacade findAttribute(String name);

    /**
     * <p>
     * Those abstraction dependencies for which this classifier is the
     * client.
     * </p>
     * @return Collection<ClassifierFacade>
     */
    public Collection<ClassifierFacade> getAbstractions();

    /**
     * <p>
     * Lists all classes associated to this one and any ancestor
     * classes (through generalization). There will be no duplicates.
     * The order of the elements is predictable.
     * </p>
     * @return Collection<ClassifierFacade>
     */
    public Collection<ClassifierFacade> getAllAssociatedClasses();

    /**
     * <p>
     * A collection containing all 'properties' of the classifier and
     * its ancestors.  Properties are any attributes and navigable
     * connecting association ends.
     * </p>
     * @return Collection
     */
    public Collection getAllProperties();

    /**
     * <p>
     * A collection containing all required and/or read-only
     * 'properties' of the classifier and its ancestors. Properties are
     * any attributes and navigable connecting association ends.
     * </p>
     * @return Collection
     */
    public Collection getAllRequiredConstructorParameters();

    /**
     * <p>
     * Gets the array type for this classifier.  If this classifier
     * already represents an array, it just returns itself.
     * </p>
     * @return ClassifierFacade
     */
    public ClassifierFacade getArray();

    /**
     * <p>
     * The name of the classifier as an array.
     * </p>
     * @return String
     */
    public String getArrayName();

    /**
     * <p>
     * Lists the classes associated to this one, there is no repitition
     * of classes. The order of the elements is predictable.
     * </p>
     * @return Collection<ClassifierFacade>
     */
    public Collection<ClassifierFacade> getAssociatedClasses();

    /**
     * <p>
     * Gets the association ends belonging to a classifier.
     * </p>
     * @return List<AssociationEndFacade>
     */
    public List<AssociationEndFacade> getAssociationEnds();

    /**
     * <p>
     * Gets the attributes that belong to the classifier.
     * </p>
     * @return List<AttributeFacade>
     */
    public List<AttributeFacade> getAttributes();

    /**
     * <p>
     * Gets all attributes for the classifier and if 'follow' is true
     * goes up the inheritance hierarchy and gets the attributes from
     * the super classes as well.
     * </p>
     * @param follow boolean
     * @return List
     */
    public List getAttributes(boolean follow);

    /**
     * <p>
     * The fully qualified name of the classifier as an array.
     * </p>
     * @return String
     */
    public String getFullyQualifiedArrayName();

    /**
     * <p>
     * Returns all those operations that could be implemented at this
     * classifier's level. This means the operations owned by this
     * classifier as well as any realized interface's operations
     * (recursively) in case this classifier itself is not already an
     * interface, or generalized when this classifier is an interface.
     * </p>
     * @return Collection<OperationFacade>
     */
    public Collection<OperationFacade> getImplementationOperations();

    /**
     * <p>
     * A comma separated list of the fully qualified names of all
     * implemented interfaces.
     * </p>
     * @return String
     */
    public String getImplementedInterfaceList();

    /**
     * <p>
     * Those attributes that are scoped to an instance of this class.
     * </p>
     * @return Collection<AttributeFacade>
     */
    public Collection<AttributeFacade> getInstanceAttributes();

    /**
     * <p>
     * Those operations that are scoped to an instance of this class.
     * </p>
     * @return List<OperationFacade>
     */
    public List<OperationFacade> getInstanceOperations();

    /**
     * <p>
     * Those interfaces that are abstractions of this classifier, this
     * basically means this classifier realizes them.
     * </p>
     * @return Collection<ClassifierFacade>
     */
    public Collection<ClassifierFacade> getInterfaceAbstractions();

    /**
     * <p>
     * A String representing a new Constructor declaration for this
     * classifier type to be used in a Java environment.
     * </p>
     * @return String
     */
    public String getJavaNewString();

    /**
     * <p>
     * A String representing the null-value for this classifier type to
     * be used in a Java environment.
     * </p>
     * @return String
     */
    public String getJavaNullString();

    /**
     * <p>
     * The other ends of this classifier's association ends which are
     * navigable.
     * </p>
     * @return Collection<ClassifierFacade>
     */
    public Collection<ClassifierFacade> getNavigableConnectingEnds();

    /**
     * <p>
     * Get the other ends of this classifier's association ends which
     * are navigable and if 'follow' is true goes up the inheritance
     * hierarchy and gets the super association ends as well.
     * </p>
     * @param follow boolean
     * @return List
     */
    public List getNavigableConnectingEnds(boolean follow);

    /**
     * <p>
     * Assuming that the classifier is an array, this will return the
     * non array type of the classifier from
     * </p>
     * <p>
     * the model.  If the classifier is NOT an array, it will just
     * return itself.
     * </p>
     * @return ClassifierFacade
     */
    public ClassifierFacade getNonArray();

    /**
     * <p>
     * The attributes from this classifier in the form of an operation
     * call (this example would be in Java): '(String attributeOne,
     * String attributeTwo).  If there were no attributes on the
     * classifier, the result would be an empty '()'.
     * </p>
     * @return String
     */
    public String getOperationCallFromAttributes();

    /**
     * <p>
     * The operations owned by this classifier.
     * </p>
     * @return List<OperationFacade>
     */
    public List<OperationFacade> getOperations();

    /**
     * <p>
     * A collection containing all 'properties' of the classifier. 
     * Properties are any attributes and navigable connecting
     * association ends.
     * </p>
     * @return List
     */
    public List getProperties();

    /**
     * <p>
     * Gets all properties (attributes and navigable association ends)
     * for the classifier and if 'follow' is true goes up the
     * inheritance hierarchy and gets the properties from the super
     * classes as well.
     * </p>
     * @param follow boolean
     * @return List
     */
    public List getProperties(boolean follow);

    /**
     * <p>
     * A collection containing all required and/or read-only
     * 'properties' of the classifier.  Properties are any attributes
     * and navigable connecting association ends.
     * </p>
     * @return Collection
     */
    public Collection getRequiredConstructorParameters();

    /**
     * <p>
     * Returns the serial version UID of the underlying model element.
     * </p>
     * @return long
     */
    public long getSerialVersionUID();

    /**
     * <p>
     * Those attributes that are scoped to the definition of this
     * class.
     * </p>
     * @return Collection<AttributeFacade>
     */
    public Collection<AttributeFacade> getStaticAttributes();

    /**
     * <p>
     * Those operations that are scoped to the definition of this
     * class.
     * </p>
     * @return List<OperationFacade>
     */
    public List<OperationFacade> getStaticOperations();

    /**
     * <p>
     * This class' superclass, returns the generalization if it is a
     * ClassifierFacade, null otherwise.
     * </p>
     * @return ClassifierFacade
     */
    public ClassifierFacade getSuperClass();

    /**
     * <p>
     * The wrapper name for this classifier if a mapped type has a
     * defined wrapper class (ie. 'long' maps to 'Long').  If the
     * classifier doesn't have a wrapper defined for it, this method
     * will return a null.  Note that wrapper mappings must be defined
     * for the namespace by defining the 'wrapperMappingsUri', this
     * property must point to the location of the mappings file which
     * maps the primitives to wrapper types.
     * </p>
     * @return String
     */
    public String getWrapperName();

    /**
     * <p>
     * Indicates if this classifier is 'abstract'.
     * </p>
     * @return boolean
     */
    public boolean isAbstract();

    /**
     * <p>
     * True if this classifier represents an array type. False
     * otherwise.
     * </p>
     * @return boolean
     */
    public boolean isArrayType();

    /**
     * 
     * @return boolean
     */
    public boolean isAssociationClass();

    /**
     * <p>
     * Returns true if this type represents a Blob type.
     * </p>
     * @return boolean
     */
    public boolean isBlobType();

    /**
     * <p>
     * Indicates if this type represents a boolean type or not.
     * </p>
     * @return boolean
     */
    public boolean isBooleanType();

    /**
     * <p>
     * Indicates if this type represents a char, Character, or
     * java.lang.Character type or not.
     * </p>
     * @return boolean
     */
    public boolean isCharacterType();

    /**
     * <p>
     * Returns true if this type represents a Clob type.
     * </p>
     * @return boolean
     */
    public boolean isClobType();

    /**
     * <p>
     * True if this classifier represents a collection type. False
     * otherwise.
     * </p>
     * @return boolean
     */
    public boolean isCollectionType();

    /**
     * <p>
     * True/false depending on whether or not this classifier
     * represents a datatype. A data type is a type whose instances are
     * identified only by their value. A data type may contain
     * attributes to support the modeling of structured data types.
     * </p>
     * @return boolean
     */
    public boolean isDataType();

    /**
     * <p>
     * True when this classifier is a date type.
     * </p>
     * @return boolean
     */
    public boolean isDateType();

    /**
     * <p>
     * Indicates if this type represents a Double type or not.
     * </p>
     * @return boolean
     */
    public boolean isDoubleType();

    /**
     * <p>
     * Indicates whether or not this classifier represents an
     * "EmbeddedValue'.
     * </p>
     * @return boolean
     */
    public boolean isEmbeddedValue();

    /**
     * <p>
     * True if this classifier is in fact marked as an enumeration.
     * </p>
     * @return boolean
     */
    public boolean isEnumeration();

    /**
     * <p>
     * Returns true if this type represents a 'file' type.
     * </p>
     * @return boolean
     */
    public boolean isFileType();

    /**
     * <p>
     * Indicates if this type represents a Float type or not.
     * </p>
     * @return boolean
     */
    public boolean isFloatType();

    /**
     * <p>
     * Indicates if this type represents an int or Integer or
     * java.lang.Integer type or not.
     * </p>
     * @return boolean
     */
    public boolean isIntegerType();

    /**
     * <p>
     * True/false depending on whether or not this Classifier
     * represents an interface.
     * </p>
     * @return boolean
     */
    public boolean isInterface();

    /**
     * <p>
     * True if this classifier cannot be extended and represent a leaf
     * in the inheritance tree.
     * </p>
     * @return boolean
     */
    public boolean isLeaf();

    /**
     * <p>
     * True if this classifier represents a list type. False otherwise.
     * </p>
     * @return boolean
     */
    public boolean isListType();

    /**
     * <p>
     * Indicates if this type represents a Long type or not.
     * </p>
     * @return boolean
     */
    public boolean isLongType();

    /**
     * <p>
     * Indicates whether or not this classifier represents a Map type.
     * </p>
     * @return boolean
     */
    public boolean isMapType();

    /**
     * <p>
     * Indicates whether or not this classifier represents a primitive
     * type.
     * </p>
     * @return boolean
     */
    public boolean isPrimitive();

    /**
     * <p>
     * True if this classifier represents a set type. False otherwise.
     * </p>
     * @return boolean
     */
    public boolean isSetType();

    /**
     * <p>
     * Indicates whether or not this classifier represents a string
     * type.
     * </p>
     * @return boolean
     */
    public boolean isStringType();

    /**
     * <p>
     * Indicates whether or not this classifier represents a time type.
     * </p>
     * @return boolean
     */
    public boolean isTimeType();

    /**
     * <p>
     * Returns true if this type is a wrapped primitive type.
     * </p>
     * @return boolean
     */
    public boolean isWrappedPrimitive();
}