// license-header java merge-point
//
// Attention: generated code (by Metafacade.vsl) - do not modify!
//
package org.andromda.metafacades.uml;

import java.util.List;

/**
 * <p>
 * Represents a "front-end" action. An action is some action that
 * is taken when a front-end even occurs.
 * </p>
 *
 * Metafacade interface to be used by AndroMDA cartridges.
 */
public interface FrontEndAction
    extends FrontEndForward
{
    /**
     * Indicates the metafacade type (used for metafacade mappings).
     *
     * @return boolean always <code>true</code>
     */
    public boolean isFrontEndActionMetaType();

    /**
     * <p>
     * Finds the parameter on this action having the given name, if no
     * parameter is found, null is returned instead.
     * </p>
     * @param name String
     * @return ParameterFacade
     */
    public ParameterFacade findParameter(String name);

    /**
     * <p>
     * All action forwards for this foward. Each action forward either
     * calls a view or another use-case (which is essentially an
     * action).
     * </p>
     * @return List<FrontEndForward>
     */
    public List<FrontEndForward> getActionForwards();

    /**
     * <p>
     * All action states visited by this action.
     * </p>
     * @return List<FrontEndActionState>
     */
    public List<FrontEndActionState> getActionStates();

    /**
     * <p>
     * The controller that will handle the execution of this front-end
     * action. This controller is set as the context of the activity
     * graph (and therefore also of the use-case).
     * </p>
     * @return FrontEndController
     */
    public FrontEndController getController();

    /**
     * <p>
     * All the transitions coming out of decision points. These
     * transitions should all carry guards.
     * </p>
     * @return List<FrontEndForward>
     */
    public List<FrontEndForward> getDecisionTransitions();

    /**
     * <p>
     * The controller operations to which this action defers, the order
     * is preserved.
     * </p>
     * @return List<FrontEndControllerOperation>
     */
    public List<FrontEndControllerOperation> getDeferredOperations();

    /**
     * <p>
     * Form fields for this action. Form fields are those parameters
     * that can be altered by the user on a corresponding view at
     * runtime.
     * </p>
     * @return List<FrontEndParameter>
     */
    public List<FrontEndParameter> getFormFields();

    /**
     * <p>
     * The StateVertex (FrontEndView or PseudostateFacade) on which
     * this action can be triggered.
     * </p>
     * @return StateVertexFacade
     */
    public StateVertexFacade getInput();

    /**
     * <p>
     * All parameters sent by this "front-end" action.
     * </p>
     * @return List<FrontEndParameter>
     */
    public List<FrontEndParameter> getParameters();

    /**
     * <p>
     * All views that can be possibly targetted by triggering this
     * action.
     * </p>
     * @return List<FrontEndView>
     */
    public List<FrontEndView> getTargetViews();

    /**
     * <p>
     * All the transitions that make up this action, this directly maps
     * onto the forwards.
     * </p>
     * @return List<FrontEndForward>
     */
    public List<FrontEndForward> getTransitions();

    /**
     * <p>
     * Indicates if this action represents the beginning of the
     * front-end use case or not.
     * </p>
     * @return boolean
     */
    public boolean isUseCaseStart();
}