// license-header java merge-point
//
// Attention: generated code (by Metafacade.vsl) - do not modify!
//
package org.andromda.metafacades.uml;

import java.util.Collection;
import org.andromda.core.metafacade.ModelValidationMessage;

/**
 * <p>
 * Represents a model element. It may be an Element or
 * NamedElement. A named element is an element in a model that may
 * have a name. An element is a constituent of a model. As such, it
 * has the capability of owning other elements.
 * </p>
 *
 * Metafacade interface to be used by AndroMDA cartridges.
 */
public interface ModelElementFacade
{
    /**
     * Indicates the metafacade type (used for metafacade mappings).
     *
     * @return boolean always <code>true</code>
     */
    public boolean isModelElementFacadeMetaType();

    /**
     * Provides any required initialization of the metafacade.
     */
    void initialize();

    /**
     * Gets the metafacade that acts as the <code>owner</code> of this metafacade.
     * (for example: an operation is an owner of its parameters, etc). This is used
     * by AndroMDA's validation framework to provide more context as to where the
     * error has occurred.
     * @return Object the Validation Owner
     */
    public Object getValidationOwner();

    /**
     * Gets the name of the metafacade used within validation messages.  This provides
     * the full name of the metafacade.
     * @return String the Validation Name
     */
    public String getValidationName();

    /**
     * Performs validation of any invariants found on this model element
     * and stores the messages within the <code>validationMessages</code>
     * collection.
     *
     * @param validationMessages the collection of messages to which additional
     *        validation messages will be added if invariants are broken.
     */
    void validateInvariants(Collection<ModelValidationMessage> validationMessages);

    /**
     * <p>
     * Copies all tagged values from the given ModelElementFacade to
     * this model element facade.
     * </p>
     * @param element ModelElementFacade
     */
    public void copyTaggedValues(ModelElementFacade element);

    /**
     * <p>
     * Finds the tagged value with the specified 'tagName'. In case
     * there are more values the first one found will be returned.
     * </p>
     * @param tagName String
     * @return Object
     */
    public Object findTaggedValue(String tagName);

    /**
     * <p>
     * Returns all the values for the tagged value with the specified
     * name. The returned collection will contains only String
     * instances, or will be empty. Never null.
     * </p>
     * @param tagName String
     * @return Collection
     */
    public Collection findTaggedValues(String tagName);

    /**
     * <p>
     * Returns the fully qualified name of the model element. The fully
     * qualified name includes complete package qualified name of the
     * underlying model element. The templates parameter will be
     * replaced by the correct one given the binding relation of the
     * parameter to this element.
     * </p>
     * @param bindedElement ModelElementFacade
     * @return String
     */
    public String getBindedFullyQualifiedName(ModelElementFacade bindedElement);

    /**
     * <p>
     * Gets all constraints belonging to the model element.
     * </p>
     * @return Collection<ConstraintFacade>
     */
    public Collection<ConstraintFacade> getConstraints();

    /**
     * <p>
     * Returns the constraints of the argument kind that have been
     * placed onto this model. Typical kinds are "inv", "pre" and
     * "post". Other kinds are possible.
     * </p>
     * @param kind String
     * @return Collection
     */
    public Collection getConstraints(String kind);

    /**
     * <p>
     * Gets the documentation for the model element, The indent
     * argument is prefixed to each line. By default this method wraps
     * lines after 64 characters.
     * </p>
     * <p>
     * This method is equivalent to <code>getDocumentation(indent,
     * 64)</code>.
     * </p>
     * @param indent String
     * @return String
     */
    public String getDocumentation(String indent);

    /**
     * <p>
     * This method returns the documentation for this model element,
     * with the lines wrapped after the specified number of characters,
     * values of less than 1 will indicate no line wrapping is
     * required. By default paragraphs are returned as HTML.
     * </p>
     * <p>
     * This method is equivalent to <code>getDocumentation(indent,
     * lineLength, true)</code>.
     * </p>
     * @param indent String
     * @param lineLength int
     * @return String
     */
    public String getDocumentation(String indent, int lineLength);

    /**
     * 
     * @param indent String
     * @param lineLength int
     * @param htmlStyle boolean
     * @return String
     */
    public String getDocumentation(String indent, int lineLength, boolean htmlStyle);

    /**
     * <p>
     * The fully qualified name of this model element.
     * </p>
     * @return String
     */
    public String getFullyQualifiedName();

    /**
     * <p>
     * Returns the fully qualified name of the model element. The fully
     * qualified name includes complete package qualified name of the
     * underlying model element.  If modelName is true, then the
     * original name of the model element (the name contained within
     * the model) will be the name returned, otherwise a name from a
     * language mapping will be returned.
     * </p>
     * @param modelName boolean
     * @return String
     */
    public String getFullyQualifiedName(boolean modelName);

    /**
     * <p>
     * Returns the fully qualified name as a path, the returned value
     * always starts with out a slash '/'.
     * </p>
     * @return String
     */
    public String getFullyQualifiedNamePath();

    /**
     * <p>
     * Gets the unique identifier of the underlying model element.
     * </p>
     * @return String
     */
    public String getId();

    /**
     * <p>
     * UML2: Retrieves the keywords for this element. Used to modify
     * implementation properties which are not represented by other
     * properties, i.e. native, transient, volatile, synchronized,
     * (added annotations) override, deprecated. Can also be used to
     * suppress compiler warnings: (added annotations) unchecked,
     * fallthrough, path, serial, finally, all. Annotations require
     * JDK5 compiler level.
     * </p>
     * @return Collection<String>
     */
    public Collection<String> getKeywords();

    /**
     * <p>
     * UML2: Retrieves a localized label for this named element.
     * </p>
     * @return String
     */
    public String getLabel();

    /**
     * <p>
     * The language mappings that have been set for this model elemnt.
     * </p>
     * @return TypeMappings
     */
    public TypeMappings getLanguageMappings();

    /**
     * 
     * @return ModelFacade
     */
    public ModelFacade getModel();

    /**
     * <p>
     * The name of the model element.
     * </p>
     * @return String
     */
    public String getName();

    /**
     * <p>
     * Gets the package to which this model element belongs.
     * </p>
     * @return ModelElementFacade
     */
    public ModelElementFacade getPackage();

    /**
     * <p>
     * The name of this model element's package.
     * </p>
     * @return String
     */
    public String getPackageName();

    /**
     * <p>
     * Gets the package name (optionally providing the ability to
     * retrieve the model name and not the mapped name).
     * </p>
     * @param modelName boolean
     * @return String
     */
    public String getPackageName(boolean modelName);

    /**
     * <p>
     * Returns the package as a path, the returned value always starts
     * with out a slash '/'.
     * </p>
     * @return String
     */
    public String getPackagePath();

    /**
     * <p>
     * UML2: Returns the value of the 'Qualified Name' attribute. A
     * name which allows the NamedElement to be identified within a
     * hierarchy of nested Namespaces. It is constructed from the names
     * of the containing namespaces starting at the root of the
     * hierarchy and ending with the name of the NamedElement itself.
     * </p>
     * @return String
     */
    public String getQualifiedName();

    /**
     * <p>
     * Gets the root package for the model element.
     * </p>
     * @return PackageFacade
     */
    public PackageFacade getRootPackage();

    /**
     * <p>
     * Gets the dependencies for which this model element is the
     * source.
     * </p>
     * @return Collection<DependencyFacade>
     */
    public Collection<DependencyFacade> getSourceDependencies();

    /**
     * <p>
     * If this model element is the context of an activity graph, this
     * represents that activity graph.
     * </p>
     * @return StateMachineFacade
     */
    public StateMachineFacade getStateMachineContext();

    /**
     * <p>
     * The collection of ALL stereotype names for this model element.
     * </p>
     * @return Collection<String>
     */
    public Collection<String> getStereotypeNames();

    /**
     * <p>
     * Gets all stereotypes for this model element.
     * </p>
     * @return Collection<StereotypeFacade>
     */
    public Collection<StereotypeFacade> getStereotypes();

    /**
     * 
     * @return Collection<TaggedValueFacade>
     */
    public Collection<TaggedValueFacade> getTaggedValues();

    /**
     * <p>
     * Gets the dependencies for which this model element is the
     * target.
     * </p>
     * @return Collection<DependencyFacade>
     */
    public Collection<DependencyFacade> getTargetDependencies();

    /**
     * 
     * @param parameterName String
     * @return Object
     */
    public Object getTemplateParameter(String parameterName);

    /**
     * 
     * @return Collection<TemplateParameterFacade>
     */
    public Collection<TemplateParameterFacade> getTemplateParameters();

    /**
     * <p>
     * The visibility (i.e. public, private, protected or package) of
     * the model element, will attempt a lookup for these values in the
     * language mappings (if any).
     * </p>
     * @return String
     */
    public String getVisibility();

    /**
     * <p>
     * Returns true if the model element has the exact stereotype
     * (meaning no stereotype inheritance is taken into account when
     * searching for the stereotype), false otherwise.
     * </p>
     * @param stereotypeName String
     * @return boolean
     */
    public boolean hasExactStereotype(String stereotypeName);

    /**
     * <p>
     * Does the UML Element contain the named Keyword? Keywords can be
     * separated by space, comma, pipe, semicolon, or << >>
     * </p>
     * @param keywordName String
     * @return boolean
     */
    public boolean hasKeyword(String keywordName);

    /**
     * <p>
     * Returns true if the model element has the specified stereotype. 
     * If the stereotype itself does not match, then a search will be
     * made up the stereotype inheritance hierarchy, and if one of the
     * stereotype's ancestors has a matching name this method will
     * return true, false otherwise.
     * </p>
     * <p>
     * For example, if we have a certain stereotype called
     * <<exception>> and a model element has a stereotype called
     * <<applicationException>> which extends <<exception>>, when
     * calling this method with 'stereotypeName' defined as 'exception'
     * the method would return true since <<applicationException>>
     * inherits from <<exception>>.  If you want to check if the model
     * element has the exact stereotype, then use the method
     * 'hasExactStereotype' instead.
     * </p>
     * @param stereotypeName String
     * @return boolean
     */
    public boolean hasStereotype(String stereotypeName);

    /**
     * 
     * @return boolean
     */
    public boolean isBindingDependenciesPresent();

    /**
     * <p>
     * Indicates if any constraints are present on this model element.
     * </p>
     * @return boolean
     */
    public boolean isConstraintsPresent();

    /**
     * <p>
     * Indicates if any documentation is present on this model element.
     * </p>
     * @return boolean
     */
    public boolean isDocumentationPresent();

    /**
     * <p>
     * True if this element name is a reserved word in Java, C#, ANSI
     * or ISO C, C++, JavaScript.
     * </p>
     * @return boolean
     */
    public boolean isReservedWord();

    /**
     * 
     * @return boolean
     */
    public boolean isTemplateParametersPresent();

    /**
     * <p>
     * Searches for the constraint with the specified 'name' on this
     * model element, and if found translates it using the specified
     * 'translation' from a translation library discovered by the
     * framework.
     * </p>
     * @param name String
     * @param translation String
     * @return String
     */
    public String translateConstraint(String name, String translation);

    /**
     * <p>
     * Translates all constraints belonging to this model element with
     * the given 'translation'.
     * </p>
     * @param translation String
     * @return String[]
     */
    public String[] translateConstraints(String translation);

    /**
     * <p>
     * Translates the constraints of the specified 'kind' belonging to
     * this model element.
     * </p>
     * @param kind String
     * @param translation String
     * @return String[]
     */
    public String[] translateConstraints(String kind, String translation);
}