// license-header java merge-point
//
// Attention: generated code (by Metafacade.vsl) - do not modify!
//
package org.andromda.metafacades.uml;

import java.util.Collection;

/**
 * <p>
 * A behavioral feature of a classifier that specifies the name,
 * type, parameters, and constraints for invoking an associated
 * behavior. May invoke both the execution of method behaviors as
 * well as other behavioral responses.
 * </p>
 *
 * Metafacade interface to be used by AndroMDA cartridges.
 */
public interface OperationFacade
    extends ModelElementFacade
{
    /**
     * Indicates the metafacade type (used for metafacade mappings).
     *
     * @return boolean always <code>true</code>
     */
    public boolean isOperationFacadeMetaType();

    /**
     * <p>
     * Finds the parameter on this operation having the given name, if
     * no parameter is found, null is returned instead.
     * </p>
     * @param name String
     * @return ParameterFacade
     */
    public ParameterFacade findParameter(String name);

    /**
     * <p>
     * Searches the given feature for the specified tag.
     * </p>
     * <p>
     * If the follow boolean is set to true then the search will
     * continue from the class operation to the class itself and then
     * up the class hierarchy.
     * </p>
     * @param name String
     * @param follow boolean
     * @return Object
     */
    public Object findTaggedValue(String name, boolean follow);

    /**
     * <p>
     * A comma separated list of all argument names.
     * </p>
     * @return String
     */
    public String getArgumentNames();

    /**
     * 
     * @return String
     */
    public String getArgumentTypeNames();

    /**
     * 
     * @return Collection<ParameterFacade>
     */
    public Collection<ParameterFacade> getArguments();

    /**
     * 
     * @return String
     */
    public String getCall();

    /**
     * <p>
     * Returns the concurrency modifier for this operation (i.e.
     * concurrent, guarded or sequential) of the model element, will
     * attempt a lookup for these values in the language mappings (if
     * any).
     * </p>
     * @return String
     */
    public String getConcurrency();

    /**
     * <p>
     * A comma separated list containing all exceptions that this
     * operation throws.  Exceptions are determined through
     * dependencies that have the target element stereotyped as
     * <<Exception>>.
     * </p>
     * @return String
     */
    public String getExceptionList();

    /**
     * <p>
     * Returns a comma separated list of exceptions appended to the
     * comma separated list of fully qualified 'initialException'
     * classes passed in to this method.
     * </p>
     * @param initialExceptions String
     * @return String
     */
    public String getExceptionList(String initialExceptions);

    /**
     * <p>
     * A collection of all exceptions thrown by this operation.
     * </p>
     * @return Collection
     */
    public Collection getExceptions();

    /**
     * <p>
     * Return Type with multiplicity taken into account. UML14 does not
     * allow multiplicity *.
     * </p>
     * @return String
     */
    public String getGetterSetterReturnTypeName();

    /**
     * <p>
     * the lower value for the multiplicity
     * </p>
     * <p>
     * -only applicable for UML2
     * </p>
     * @return int
     */
    public int getLower();

    /**
     * <p>
     * Returns the operation method body determined from UML sequence
     * diagrams or other UML sources.
     * </p>
     * @return String
     */
    public String getMethodBody();

    /**
     * <p>
     * The operation this operation overrides, null if this operation
     * is not overriding.
     * </p>
     * @return OperationFacade
     */
    public OperationFacade getOverriddenOperation();

    /**
     * <p>
     * Gets the owner of this operation
     * </p>
     * @return ClassifierFacade
     */
    public ClassifierFacade getOwner();

    /**
     * 
     * @return Collection<ParameterFacade>
     */
    public Collection<ParameterFacade> getParameters();

    /**
     * <p>
     * The name of the operation that handles postcondition
     * constraints.
     * </p>
     * @return String
     */
    public String getPostconditionName();

    /**
     * <p>
     * The postcondition constraints belonging to this operation.
     * </p>
     * @return Collection<ConstraintFacade>
     */
    public Collection<ConstraintFacade> getPostconditions();

    /**
     * <p>
     * The call to the precondition operation.
     * </p>
     * @return String
     */
    public String getPreconditionCall();

    /**
     * <p>
     * The name of the operation that handles precondition constraints.
     * </p>
     * @return String
     */
    public String getPreconditionName();

    /**
     * <p>
     * The signature of the precondition operation.
     * </p>
     * @return String
     */
    public String getPreconditionSignature();

    /**
     * <p>
     * The precondition constraints belonging to this operation.
     * </p>
     * @return Collection<ConstraintFacade>
     */
    public Collection<ConstraintFacade> getPreconditions();

    /**
     * <p>
     * (UML2 Only). Get the actual return parameter (which may have
     * stereotypes etc).
     * </p>
     * @return ParameterFacade
     */
    public ParameterFacade getReturnParameter();

    /**
     * 
     * @return ClassifierFacade
     */
    public ClassifierFacade getReturnType();

    /**
     * 
     * @return String
     */
    public String getSignature();

    /**
     * <p>
     * Returns the signature of the operation and optionally appends
     * the argument names (if withArgumentNames is true), otherwise
     * returns the signature with just the types alone in the
     * signature.
     * </p>
     * @param withArgumentNames boolean
     * @return String
     */
    public String getSignature(boolean withArgumentNames);

    /**
     * <p>
     * Returns the signature of the operation and optionally appends
     * the given 'argumentModifier' to each argument.
     * </p>
     * @param argumentModifier String
     * @return String
     */
    public String getSignature(String argumentModifier);

    /**
     * <p>
     * A comma-separated parameter list  (type and name of each
     * parameter) of an operation.
     * </p>
     * @return String
     */
    public String getTypedArgumentList();

    /**
     * <p>
     * A comma-separated parameter list  (type and name of each
     * parameter) of an operation with an optional modifier (i.e final)
     * before each parameter.
     * </p>
     * @param modifier String
     * @return String
     */
    public String getTypedArgumentList(String modifier);

    /**
     * <p>
     * the upper value for the multiplicity (will be -1 for *)
     * </p>
     * <p>
     * - only applicable for UML2
     * </p>
     * @return int
     */
    public int getUpper();

    /**
     * 
     * @return boolean
     */
    public boolean isAbstract();

    /**
     * <p>
     * True if the operation has (i.e. throws any exceptions) false
     * otherwise.
     * </p>
     * @return boolean
     */
    public boolean isExceptionsPresent();

    /**
     * <p>
     * IsLeaf property in the operation. If true, operation is final,
     * cannot be extended or implemented by a descendant.
     * Default=false.
     * </p>
     * @return boolean
     */
    public boolean isLeaf();

    /**
     * <p>
     * UML2 only. If the return type parameter multiplicity>1 OR the
     * operation multiplicity>1. Default=false.
     * </p>
     * @return boolean
     */
    public boolean isMany();

    /**
     * <p>
     * UML2 only: If isMany (Collection type returned), is the type
     * unique within the collection.  Unique+Ordered determines
     * CollectionType implementation of return result. Default=false.
     * </p>
     * @return boolean
     */
    public boolean isOrdered();

    /**
     * <p>
     * True if this operation overrides an operation defined in an
     * ancestor class. An operation overrides when the names of the
     * operations as well as the types of the arguments are equal. The
     * return type may be different and is, as well as any exceptions,
     * ignored.
     * </p>
     * @return boolean
     */
    public boolean isOverriding();

    /**
     * <p>
     * Whether any postcondition constraints are present on this
     * operation.
     * </p>
     * @return boolean
     */
    public boolean isPostconditionsPresent();

    /**
     * <p>
     * Whether any precondition constraints are present on this
     * operation.
     * </p>
     * @return boolean
     */
    public boolean isPreconditionsPresent();

    /**
     * <p>
     * Indicates whether or not this operation is a query operation.
     * </p>
     * @return boolean
     */
    public boolean isQuery();

    /**
     * <p>
     * True/false depending on whether or not the operation has a
     * return type or not (i.e. a return type of something other than
     * void).
     * </p>
     * @return boolean
     */
    public boolean isReturnTypePresent();

    /**
     * 
     * @return boolean
     */
    public boolean isStatic();

    /**
     * <p>
     * UML2 only: for Collection return type, is the type unique within
     * the collection. Unique+Ordered determines the returned
     * CollectionType. Default=false.
     * </p>
     * @return boolean
     */
    public boolean isUnique();
}